==> blanco.plugin.stringconverter_0.0.9-eclipse3.0.zip: src/blanco/stringconverter/valueobject/BlancoStringConverterStructure.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 * ̃t@CBlancoValueObjectɂ莩܂B
 */
package blanco.stringconverter.valueobject;

import java.util.ArrayList;

/**
 * BlancoStringConverter̂ȂŗpValueObjectłB
 */
public class BlancoStringConverterStructure {
    /**
     * tB[h [name]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ϊIDw肵܂BK{ڂłB
     */
    private String fName;

    /**
     * tB[h [package]
     *
     * ڂ̌^ [java.lang.String]<br>
     * pbP[Ww肵܂BK{ڂłB
     */
    private String fPackage;

    /**
     * tB[h [description]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ϊ̐Lڂ܂B
     */
    private String fDescription;

    /**
     * tB[h [suffix]
     *
     * ڂ̌^ [java.lang.String]<br>
     * NX̌ɕt^TtBbNXB
     */
    private String fSuffix;

    /**
     * tB[h [listField]
     *
     * ڂ̌^ [java.util.ArrayList]<br>
     * Kl   [new ArrayList()]<br>
     * tB[hێ郊XgB
     */
    private ArrayList fListField = new ArrayList();

    /**
     * tB[h [name]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ϊIDw肵܂BK{ڂłB
     *
     * @param argName tB[h[name]Ɋi[l
     */
    public void setName(final String argName) {
        fName = argName;
    }

    /**
     * tB[h[name]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ϊIDw肵܂BK{ڂłB
     *
     * @return tB[h[name]Ɋi[Ăl
     */
    public String getName() {
        return fName;
    }

    /**
     * tB[h [package]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * pbP[Ww肵܂BK{ڂłB
     *
     * @param argPackage tB[h[package]Ɋi[l
     */
    public void setPackage(final String argPackage) {
        fPackage = argPackage;
    }

    /**
     * tB[h[package]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * pbP[Ww肵܂BK{ڂłB
     *
     * @return tB[h[package]Ɋi[Ăl
     */
    public String getPackage() {
        return fPackage;
    }

    /**
     * tB[h [description]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ϊ̐Lڂ܂B
     *
     * @param argDescription tB[h[description]Ɋi[l
     */
    public void setDescription(final String argDescription) {
        fDescription = argDescription;
    }

    /**
     * tB[h[description]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ϊ̐Lڂ܂B
     *
     * @return tB[h[description]Ɋi[Ăl
     */
    public String getDescription() {
        return fDescription;
    }

    /**
     * tB[h [suffix]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * NX̌ɕt^TtBbNXB
     *
     * @param argSuffix tB[h[suffix]Ɋi[l
     */
    public void setSuffix(final String argSuffix) {
        fSuffix = argSuffix;
    }

    /**
     * tB[h[suffix]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * NX̌ɕt^TtBbNXB
     *
     * @return tB[h[suffix]Ɋi[Ăl
     */
    public String getSuffix() {
        return fSuffix;
    }

    /**
     * tB[h [listField]̃Zb^[\bh
     *
     * ڂ̌^ [java.util.ArrayList]<br>
     * tB[hێ郊XgB
     *
     * @param argListField tB[h[listField]Ɋi[l
     */
    public void setListField(final ArrayList argListField) {
        fListField = argListField;
    }

    /**
     * tB[h[listField]̃Qb^[\bh
     *
     * ڂ̌^ [java.util.ArrayList]<br>
     * Kl   [new ArrayList()]<br>
     * tB[hێ郊XgB
     *
     * @return tB[h[listField]Ɋi[Ăl
     */
    public ArrayList getListField() {
        return fListField;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * IuWFNg̃V[͈͂łtoStringȂ_ɒӂėpĂB
     *
     * @return o[IuWFNg̕\B
     */
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.stringconverter.valueobject.BlancoStringConverterStructure[");
        buf.append("name=" + fName);
        buf.append(",package=" + fPackage);
        buf.append(",description=" + fDescription);
        buf.append(",suffix=" + fSuffix);
        buf.append(",listField=" + fListField);
        buf.append("]");
        return buf.toString();
    }
}

==> blanco.plugin.stringconverter_0.2.0-eclipse3.0.zip: src/blanco/stringconverter/valueobject/BlancoStringConverterStructure.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.stringconverter.valueobject;

import java.util.List;

/**
 * BlancoStringConverter̂ȂŗpValueObjectłB
 */
public class BlancoStringConverterStructure {
    /**
     * tB[h [name]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ϊIDw肵܂BK{ڂłB
     */
    private String fName;

    /**
     * tB[h [package]
     *
     * ڂ̌^ [java.lang.String]<br>
     * pbP[Ww肵܂BK{ڂłB
     */
    private String fPackage;

    /**
     * tB[h [description]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ϊ̐Lڂ܂B
     */
    private String fDescription;

    /**
     * tB[h [suffix]
     *
     * ڂ̌^ [java.lang.String]<br>
     * NX̌ɕt^TtBbNXB
     */
    private String fSuffix;

    /**
     * tB[h [fieldList]
     *
     * ڂ̌^ [java.util.List]<br>
     * Kl   [new java.util.ArrayList()]<br>
     * tB[hێ郊XgB
     */
    private List fFieldList = new java.util.ArrayList();

    /**
     * tB[h [name]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ϊIDw肵܂BK{ڂłB
     *
     * @param argName tB[h[name]Ɋi[l
     */
    public void setName(final String argName) {
        fName = argName;
    }

    /**
     * tB[h[name]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ϊIDw肵܂BK{ڂłB
     *
     * @return tB[h[name]Ɋi[Ăl
     */
    public String getName() {
        return fName;
    }

    /**
     * tB[h [package]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * pbP[Ww肵܂BK{ڂłB
     *
     * @param argPackage tB[h[package]Ɋi[l
     */
    public void setPackage(final String argPackage) {
        fPackage = argPackage;
    }

    /**
     * tB[h[package]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * pbP[Ww肵܂BK{ڂłB
     *
     * @return tB[h[package]Ɋi[Ăl
     */
    public String getPackage() {
        return fPackage;
    }

    /**
     * tB[h [description]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ϊ̐Lڂ܂B
     *
     * @param argDescription tB[h[description]Ɋi[l
     */
    public void setDescription(final String argDescription) {
        fDescription = argDescription;
    }

    /**
     * tB[h[description]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ϊ̐Lڂ܂B
     *
     * @return tB[h[description]Ɋi[Ăl
     */
    public String getDescription() {
        return fDescription;
    }

    /**
     * tB[h [suffix]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * NX̌ɕt^TtBbNXB
     *
     * @param argSuffix tB[h[suffix]Ɋi[l
     */
    public void setSuffix(final String argSuffix) {
        fSuffix = argSuffix;
    }

    /**
     * tB[h[suffix]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * NX̌ɕt^TtBbNXB
     *
     * @return tB[h[suffix]Ɋi[Ăl
     */
    public String getSuffix() {
        return fSuffix;
    }

    /**
     * tB[h [fieldList]̃Zb^[\bh
     *
     * ڂ̌^ [java.util.List]<br>
     * tB[hێ郊XgB
     *
     * @param argFieldList tB[h[fieldList]Ɋi[l
     */
    public void setFieldList(final List argFieldList) {
        fFieldList = argFieldList;
    }

    /**
     * tB[h[fieldList]̃Qb^[\bh
     *
     * ڂ̌^ [java.util.List]<br>
     * Kl   [new java.util.ArrayList()]<br>
     * tB[hێ郊XgB
     *
     * @return tB[h[fieldList]Ɋi[Ăl
     */
    public List getFieldList() {
        return fFieldList;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * IuWFNg̃V[͈͂łtoStringȂ_ɒӂėpĂB
     *
     * @return o[IuWFNg̕\B
     */
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.stringconverter.valueobject.BlancoStringConverterStructure[");
        buf.append("name=" + fName);
        buf.append(",package=" + fPackage);
        buf.append(",description=" + fDescription);
        buf.append(",suffix=" + fSuffix);
        buf.append(",fieldList=" + fFieldList);
        buf.append("]");
        return buf.toString();
    }
}
